<?php

namespace XENTR\PaidMembership\Payment;

use XF\Entity\PaymentProfile;
use XF\Entity\PurchaseRequest;
use XF\Mvc\Controller;
use XF\Purchasable\Purchase;
use XF\Payment\CallbackState;

class BankPayment extends \XF\Payment\AbstractProvider
{
	public function getTitle()
	{
		return 'Bank Payments';
	}
     public function verifyConfig(array &$options, &$errors = [])
	{
 
		  if (empty($options['account_name']))
          {
               $errors[] = \XF::phrase('xtr_bank_payment_please_enter_valid_bank_account_name');
          }
		  
		  if (empty($options['user_payment_name']))
          {
               $errors[] = \XF::phrase('xtr_bank_payment_please_enter_the_name_and_surname_of_the_payment_recipient');
          }
		  
		  if (empty($options['user_bank_account_number']))
          {
               $errors[] = \XF::phrase('xtr_bank_payment_please_enter_an_account_number_for_the_payment_recipient');
          }
		  
		  if (empty($options['user_payment_bank_branch']))
          {
               $errors[] = \XF::phrase('xtr_bank_payment_please_enter_the_bank_branch');
          }
		  
          if (empty($options['account_number']))
          {
               $errors[] = \XF::phrase('xtr_bank_payment_please_enter_valid_bank_account_number');
          }

          if (empty($options['swift_code']))
          {
               $errors[] = \XF::phrase('xtr_bank_payment_please_enter_valid_swift_code');
          }
		  if (empty($options['instructions']))
          {
               $errors[] = \XF::phrase('xtr_bank_payment_please_enter_payment_instructions');
          }
		  if (empty($options['description']))
          {
               $errors[] = \XF::phrase('xtr_bank_payment_please_enter_payment_description');
          }

          return true;
     }
     protected function getPaymentParams(PurchaseRequest $purchaseRequest, Purchase $purchase)
	{
		return [
			'paymentProfile' => $purchase->paymentProfile,
			'purchase'       => $purchase
		];
	}
     public function initiatePayment(Controller $controller, PurchaseRequest $purchaseRequest, Purchase $purchase)
	{
          $viewParams = $this->getPaymentParams($purchaseRequest, $purchase);
		return $controller->view('XENTR\PaidMembership:PaidMembership', 'xtr_bank_payment_initiate_bank_transfer', $viewParams);
     }
     public function setupCallback(\XF\Http\Request $request)
	{
          $state = new CallbackState();

          return $state;
     }
     public function getPaymentResult(CallbackState $state)
	{
          $state->paymentResult = '';
     }
     public function prepareLogData(CallbackState $state)
	{

     }
     public function supportsRecurring(PaymentProfile $paymentProfile, $unit, $amount, &$result = self::ERR_NO_RECURRING)
	{
          return false;
     }
}